/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import React from "react";
import { HashRouter } from "react-router-dom";
import { AppContextProvider } from "./context/AppContextProvider";
import { OpenApiContextProvider } from "./context/OpenApiContextProvider";
import { RoutesSwitch } from "./navigation/RoutesSwitch";
import { DeploymentWorkflowListContextProvider } from "./runtimeTools/contexts/DeploymentWorkflowListContextProvider";
import { DeploymentWorkflowDetailsContextProvider } from "./runtimeTools/contexts/DeploymentWorkflowDetailsContextProvider";

export const App = () => (
  <HashRouter>
    {nest(
      [AppContextProvider, {}],
      [OpenApiContextProvider, {}],
      [DeploymentWorkflowListContextProvider, {}],
      [DeploymentWorkflowDetailsContextProvider, {}],
      [RoutesSwitch, {}]
    )}
  </HashRouter>
);

function nest(...components: Array<[(...args: any[]) => any, object]>) {
  return components.reduceRight(
    (acc, [Component, props]) => {
      return <Component {...props}>{acc}</Component>;
    },
    <></>
  );
}
